### Version 0.8.1

- fixed COI on thresholded ridge
- improved summary statistics

### Version 0.8

- added batch processing menu
- summary statistics: time-averaged power and ensemble dynamics

### Version 0.7.6.1

- reworked the SSG, catching missing parameter crashes

### Version 0.7.6

- Added general data import options with optional missing value interpolation
- Added NaN interpolation to the core module

### Version 0.7.5

- Synthetic Signal Generator, yeah!

### Version 0.7.4

- Amplitude envelope estimation and removal

	
